@@ -41,9 +41,6 @@ class TupleValidatorABC(ABC):
         """
 
 
-ContextProjectInfo = namedtuple("ContextProjectInfo", ["key", "name"])
-
-
 ArchiveFileInfo = namedtuple("ArchiveFileInfo", ["path", "size"])
 ArchiveFileContent = namedtuple(
     "ArchiveFileInfoContent", ["path", "data", "executable"]
@@ -394,57 +391,12 @@ class ObjectStorageContext(ObjectStorageContextFileMixin):
 
     @property
     @abstractmethod
-    def project(self) -> ContextProjectInfo:
+    def metadata(self) -> "ProjectMetadataTuple":
         """Project
 
         Returns a tuple with information about this project
 
-        :return: A ContextProjectInfo
-        """
-        raise NotImplementedError()
-
-    @property
-    @abstractmethod
-    def metadata(self):
-        """Metadata
-
-        Get the metadata.json file as a dictionary
-
-        :return: Dictionary built from metadata.json for the project
-        """
-        raise NotImplementedError()
-
-    @abstractmethod
-    def writeMetadata(self, metadata):
-        """Write Metadata
-
-        Write the metadata dictionary to metadata.json.
-        TODO: Perform validation of keys?
-
-        :param metadata: Dictionary for the metadata.json object
-        :return: None
-        """
-        raise NotImplementedError()
-
-    @abstractmethod
-    def getRevision(self) -> str:
-        """Get Revision
-
-        Get the (alembic) revision for the project
-
-        :return: String revision for the project that can be used with Alembic
-        """
-        raise NotImplementedError()
-
-    @abstractmethod
-    def setRevision(self, revision: str):
-        """Set Revision
-
-        Set the revision of the project. `revision` is an Alembic revision
-        string
-
-        :param revision: Alembic revision string
-        :return: None
+        :return: A ProjectMetadataTuple
         """
         raise NotImplementedError()
 
