@@ -398,7 +398,10 @@ class GitObjectStorageContext(
 
         # Validate the item before storing
         self.validateItem(item)
-        self.validateKeyDoesNotExist(group=item.storageGroup, itemKey=item.key)
+        if item.__allowsMultiple__:
+            self.validateKeyDoesNotExist(
+                group=item.storageGroup, itemKey=item.key
+            )
 
         self.__writeItem(item)
         self.__storeReferenceToTuple(item)
